==> Chipmunk-7.0.1.tgz: Chipmunk-7.0.1/doc/API-Reference/search/all_69.js <==
var searchData=
[
  ['idlespeedthreshold',['idleSpeedThreshold',['../interface_chipmunk_space.html#ad79276e72714d0e3d8025fb51efca906',1,'ChipmunkSpace']]],
  ['impulse',['impulse',['../interface_chipmunk_constraint.html#acfae278103bd74cc1a6ad6a2aad4f1fa',1,'ChipmunkConstraint']]],
  ['info',['info',['../interface_chipmunk_point_query_info.html#acfecefbea610b5b520a81b1b251bbb71',1,'ChipmunkPointQueryInfo::info()'],['../interface_chipmunk_segment_query_info.html#a7978e8423a50400626f1b0997a35ccee',1,'ChipmunkSegmentQueryInfo::info()']]],
  ['initboxwithbody_3abb_3aradius_3a',['initBoxWithBody:bb:radius:',['../interface_chipmunk_poly_shape.html#a039b4cafc1a6935b6128ea133e48f39a',1,'ChipmunkPolyShape']]],
  ['initboxwithbody_3awidth_3aheight_3aradius_3a',['initBoxWithBody:width:height:radius:',['../interface_chipmunk_poly_shape.html#ae3ab38bf99b61df0c553e959987e11e2',1,'ChipmunkPolyShape']]],
  ['initforspace_3awithsmoothing_3awithgrabforce_3a',['initForSpace:withSmoothing:withGrabForce:',['../interface_chipmunk_multi_grab.html#ab6fe5ecc2e4de8eb9eb6f2051004028c',1,'ChipmunkMultiGrab']]],
  ['initwithblock_3a',['initWithBlock:',['../interface_chipmunk_block_sampler.html#ac6d0c4816eb61c332705c7c5e0f1d6bc',1,'ChipmunkBlockSampler']]],
  ['initwithbody_3acount_3averts_3atransform_3aradius_3a',['initWithBody:count:verts:transform:radius:',['../interface_chipmunk_poly_shape.html#a355a8d8dc8ba666e1b7d948d89c3b0e1',1,'ChipmunkPolyShape']]],
  ['initwithbody_3afrom_3ato_3aradius_3a',['initWithBody:from:to:radius:',['../interface_chipmunk_segment_shape.html#a3cd820b059b700a6039005ea5f6340ed',1,'ChipmunkSegmentShape']]],
  ['initwithbody_3aradius_3aoffset_3a',['initWithBody:radius:offset:',['../interface_chipmunk_circle_shape.html#a8dc9ca46cc2973cdf2c9adecdce694e1',1,'ChipmunkCircleShape']]],
  ['initwithbodya_3abodyb_3aanchora_3aanchorb_3a',['initWithBodyA:bodyB:anchorA:anchorB:',['../interface_chipmunk_pin_joint.html#a96fb3a0fcc6f7afc75189306c763c63a',1,'ChipmunkPinJoint::initWithBodyA:bodyB:anchorA:anchorB:()'],['../interface_chipmunk_pivot_joint.html#ac65649c91b59a1f66bcdc01958e32547',1,'ChipmunkPivotJoint::initWithBodyA:bodyB:anchorA:anchorB:()']]],
  ['initwithbodya_3abodyb_3aanchora_3aanchorb_3amin_3amax_3a',['initWithBodyA:bodyB:anchorA:anchorB:min:max:',['../interface_chipmunk_slide_joint.html#af8ebfd7311d07672d8c985e17b65b4f4',1,'ChipmunkSlideJoint']]],
  ['initwithbodya_3abodyb_3aanchora_3aanchorb_3arestlength_3astiffness_3adamping_3a',['initWithBodyA:bodyB:anchorA:anchorB:restLength:stiffness:damping:',['../interface_chipmunk_damped_spring.html#ae9f402464eb3f8a6b0d589c7139aebe2',1,'ChipmunkDampedSpring']]],
  ['initwithbodya_3abodyb_3agroovea_3agrooveb_3aanchorb_3a',['initWithBodyA:bodyB:grooveA:grooveB:anchorB:',['../interface_chipmunk_groove_joint.html#a1b8b04a829b2cd533b0af0af4713e1d5',1,'ChipmunkGrooveJoint']]],
  ['initwithbodya_3abodyb_3amin_3amax_3a',['initWithBodyA:bodyB:min:max:',['../interface_chipmunk_rotary_limit_joint.html#ac5d1450cdb9edc9d1e2724c9cd8d3772',1,'ChipmunkRotaryLimitJoint']]],
  ['initwithbodya_3abodyb_3aphase_3aratchet_3a',['initWithBodyA:bodyB:phase:ratchet:',['../interface_chipmunk_ratchet_joint.html#a1ad7e86368d09483f47296c16501498e',1,'ChipmunkRatchetJoint']]],
  ['initwithbodya_3abodyb_3aphase_3aratio_3a',['initWithBodyA:bodyB:phase:ratio:',['../interface_chipmunk_gear_joint.html#a9b12a35f261c82ee633da3976ec5c670',1,'ChipmunkGearJoint']]],
  ['initwithbodya_3abodyb_3apivot_3a',['initWithBodyA:bodyB:pivot:',['../interface_chipmunk_pivot_joint.html#a0649e8ed152934cb3a88c43139d07261',1,'ChipmunkPivotJoint']]],
  ['initwithbodya_3abodyb_3arate_3a',['initWithBodyA:bodyB:rate:',['../interface_chipmunk_simple_motor.html#a3ff57bda146262b20a47973e973273b5',1,'ChipmunkSimpleMotor']]],
  ['initwithbodya_3abodyb_3arestangle_3astiffness_3adamping_3a',['initWithBodyA:bodyB:restAngle:stiffness:damping:',['../interface_chipmunk_damped_rotary_spring.html#a733d39f7772588de1beb2005252e9d42',1,'ChipmunkDampedRotarySpring']]],
  ['initwithcellsize_3a',['initWithCellSize:',['../interface_chipmunk_point_cloud_sampler.html#ab0f5e54d9076fddd8f3a9a4b1a206eee',1,'ChipmunkPointCloudSampler']]],
  ['initwithimage_3aismask_3acontextwidth_3acontextheight_3a',['initWithImage:isMask:contextWidth:contextHeight:',['../interface_chipmunk_image_sampler.html#aebc6dff33612c59a306107071a4aa6f2',1,'ChipmunkImageSampler']]],
  ['initwithimagefile_3aismask_3a',['initWithImageFile:isMask:',['../interface_chipmunk_image_sampler.html#a30f73913c4ca0118aee0d1a49423e8dc',1,'ChipmunkImageSampler']]],
  ['initwithmass_3aandmoment_3a',['initWithMass:andMoment:',['../interface_chipmunk_body.html#acc3839d7874e4522d71994aefbe9e3ce',1,'ChipmunkBody']]],
  ['initwithsampler_3aspace_3atilesize_3asamplespertile_3acachesize_3a',['initWithSampler:space:tileSize:samplesPerTile:cacheSize:',['../interface_chipmunk_abstract_tile_cache.html#a5a7090df1c395f9e5354f41b99003b34',1,'ChipmunkAbstractTileCache']]],
  ['initwithsamplingfunction_3a',['initWithSamplingFunction:',['../interface_chipmunk_abstract_sampler.html#ab02d0f11c24948ed66fd36bf914c38bb',1,'ChipmunkAbstractSampler']]],
  ['initwithwidth_3aheight_3acolorspace_3abitmapinfo_3acomponent_3a',['initWithWidth:height:colorSpace:bitmapInfo:component:',['../interface_chipmunk_c_g_context_sampler.html#a60d99d43cd8cf5104fd3112ea71f4fcd',1,'ChipmunkCGContextSampler']]],
  ['initwithwidth_3aheight_3astride_3abytesperpixel_3acomponent_3aflip_3apixeldata_3a',['initWithWidth:height:stride:bytesPerPixel:component:flip:pixelData:',['../interface_chipmunk_bitmap_sampler.html#a556e7e35a2005c72ba298a720e55c6d5',1,'ChipmunkBitmapSampler']]],
  ['isclosed',['isClosed',['../interface_chipmunk_polyline.html#aa554c304a9c991350ac69c1ae4ce1adb',1,'ChipmunkPolyline']]],
  ['issleeping',['isSleeping',['../interface_chipmunk_body.html#aff377602948f0d6c9268342403ddf906',1,'ChipmunkBody']]],
  ['iterations',['iterations',['../interface_chipmunk_space.html#a14ae29e48719422333bc51ebfc292553',1,'ChipmunkSpace']]]
];

==> Chipmunk-7.0.3.tgz: Chipmunk-7.0.3/doc/API-Reference/search/all_69.js <==
var searchData=
[
  ['idlespeedthreshold',['idleSpeedThreshold',['../interface_chipmunk_space.html#ad79276e72714d0e3d8025fb51efca906',1,'ChipmunkSpace']]],
  ['impulse',['impulse',['../interface_chipmunk_constraint.html#acfae278103bd74cc1a6ad6a2aad4f1fa',1,'ChipmunkConstraint']]],
  ['info',['info',['../interface_chipmunk_point_query_info.html#acfecefbea610b5b520a81b1b251bbb71',1,'ChipmunkPointQueryInfo::info()'],['../interface_chipmunk_segment_query_info.html#a7978e8423a50400626f1b0997a35ccee',1,'ChipmunkSegmentQueryInfo::info()']]],
  ['initboxwithbody_3abb_3aradius_3a',['initBoxWithBody:bb:radius:',['../interface_chipmunk_poly_shape.html#a039b4cafc1a6935b6128ea133e48f39a',1,'ChipmunkPolyShape']]],
  ['initboxwithbody_3awidth_3aheight_3aradius_3a',['initBoxWithBody:width:height:radius:',['../interface_chipmunk_poly_shape.html#ae3ab38bf99b61df0c553e959987e11e2',1,'ChipmunkPolyShape']]],
  ['initforspace_3awithsmoothing_3awithgrabforce_3a',['initForSpace:withSmoothing:withGrabForce:',['../interface_chipmunk_multi_grab.html#ab6fe5ecc2e4de8eb9eb6f2051004028c',1,'ChipmunkMultiGrab']]],
  ['initwithblock_3a',['initWithBlock:',['../interface_chipmunk_block_sampler.html#ac6d0c4816eb61c332705c7c5e0f1d6bc',1,'ChipmunkBlockSampler']]],
  ['initwithbody_3acount_3averts_3atransform_3aradius_3a',['initWithBody:count:verts:transform:radius:',['../interface_chipmunk_poly_shape.html#a355a8d8dc8ba666e1b7d948d89c3b0e1',1,'ChipmunkPolyShape']]],
  ['initwithbody_3afrom_3ato_3aradius_3a',['initWithBody:from:to:radius:',['../interface_chipmunk_segment_shape.html#a3cd820b059b700a6039005ea5f6340ed',1,'ChipmunkSegmentShape']]],
  ['initwithbody_3aradius_3aoffset_3a',['initWithBody:radius:offset:',['../interface_chipmunk_circle_shape.html#a8dc9ca46cc2973cdf2c9adecdce694e1',1,'ChipmunkCircleShape']]],
  ['initwithbodya_3abodyb_3aanchora_3aanchorb_3a',['initWithBodyA:bodyB:anchorA:anchorB:',['../interface_chipmunk_pin_joint.html#a96fb3a0fcc6f7afc75189306c763c63a',1,'ChipmunkPinJoint::initWithBodyA:bodyB:anchorA:anchorB:()'],['../interface_chipmunk_pivot_joint.html#ac65649c91b59a1f66bcdc01958e32547',1,'ChipmunkPivotJoint::initWithBodyA:bodyB:anchorA:anchorB:()']]],
  ['initwithbodya_3abodyb_3aanchora_3aanchorb_3amin_3amax_3a',['initWithBodyA:bodyB:anchorA:anchorB:min:max:',['../interface_chipmunk_slide_joint.html#af8ebfd7311d07672d8c985e17b65b4f4',1,'ChipmunkSlideJoint']]],
  ['initwithbodya_3abodyb_3aanchora_3aanchorb_3arestlength_3astiffness_3adamping_3a',['initWithBodyA:bodyB:anchorA:anchorB:restLength:stiffness:damping:',['../interface_chipmunk_damped_spring.html#ae9f402464eb3f8a6b0d589c7139aebe2',1,'ChipmunkDampedSpring']]],
  ['initwithbodya_3abodyb_3agroovea_3agrooveb_3aanchorb_3a',['initWithBodyA:bodyB:grooveA:grooveB:anchorB:',['../interface_chipmunk_groove_joint.html#a1b8b04a829b2cd533b0af0af4713e1d5',1,'ChipmunkGrooveJoint']]],
  ['initwithbodya_3abodyb_3amin_3amax_3a',['initWithBodyA:bodyB:min:max:',['../interface_chipmunk_rotary_limit_joint.html#ac5d1450cdb9edc9d1e2724c9cd8d3772',1,'ChipmunkRotaryLimitJoint']]],
  ['initwithbodya_3abodyb_3aphase_3aratchet_3a',['initWithBodyA:bodyB:phase:ratchet:',['../interface_chipmunk_ratchet_joint.html#a1ad7e86368d09483f47296c16501498e',1,'ChipmunkRatchetJoint']]],
  ['initwithbodya_3abodyb_3aphase_3aratio_3a',['initWithBodyA:bodyB:phase:ratio:',['../interface_chipmunk_gear_joint.html#a9b12a35f261c82ee633da3976ec5c670',1,'ChipmunkGearJoint']]],
  ['initwithbodya_3abodyb_3apivot_3a',['initWithBodyA:bodyB:pivot:',['../interface_chipmunk_pivot_joint.html#a0649e8ed152934cb3a88c43139d07261',1,'ChipmunkPivotJoint']]],
  ['initwithbodya_3abodyb_3arate_3a',['initWithBodyA:bodyB:rate:',['../interface_chipmunk_simple_motor.html#a3ff57bda146262b20a47973e973273b5',1,'ChipmunkSimpleMotor']]],
  ['initwithbodya_3abodyb_3arestangle_3astiffness_3adamping_3a',['initWithBodyA:bodyB:restAngle:stiffness:damping:',['../interface_chipmunk_damped_rotary_spring.html#a733d39f7772588de1beb2005252e9d42',1,'ChipmunkDampedRotarySpring']]],
  ['initwithcellsize_3a',['initWithCellSize:',['../interface_chipmunk_point_cloud_sampler.html#ab0f5e54d9076fddd8f3a9a4b1a206eee',1,'ChipmunkPointCloudSampler']]],
  ['initwithimage_3aismask_3acontextwidth_3acontextheight_3a',['initWithImage:isMask:contextWidth:contextHeight:',['../interface_chipmunk_image_sampler.html#aebc6dff33612c59a306107071a4aa6f2',1,'ChipmunkImageSampler']]],
  ['initwithimagefile_3aismask_3a',['initWithImageFile:isMask:',['../interface_chipmunk_image_sampler.html#a30f73913c4ca0118aee0d1a49423e8dc',1,'ChipmunkImageSampler']]],
  ['initwithmass_3aandmoment_3a',['initWithMass:andMoment:',['../interface_chipmunk_body.html#acc3839d7874e4522d71994aefbe9e3ce',1,'ChipmunkBody']]],
  ['initwithsampler_3aspace_3atilesize_3asamplespertile_3acachesize_3a',['initWithSampler:space:tileSize:samplesPerTile:cacheSize:',['../interface_chipmunk_abstract_tile_cache.html#a5a7090df1c395f9e5354f41b99003b34',1,'ChipmunkAbstractTileCache']]],
  ['initwithsamplingfunction_3a',['initWithSamplingFunction:',['../interface_chipmunk_abstract_sampler.html#ab02d0f11c24948ed66fd36bf914c38bb',1,'ChipmunkAbstractSampler']]],
  ['initwithwidth_3aheight_3acolorspace_3abitmapinfo_3acomponent_3a',['initWithWidth:height:colorSpace:bitmapInfo:component:',['../interface_chipmunk_c_g_context_sampler.html#a60d99d43cd8cf5104fd3112ea71f4fcd',1,'ChipmunkCGContextSampler']]],
  ['initwithwidth_3aheight_3astride_3abytesperpixel_3acomponent_3aflip_3apixeldata_3a',['initWithWidth:height:stride:bytesPerPixel:component:flip:pixelData:',['../interface_chipmunk_bitmap_sampler.html#a556e7e35a2005c72ba298a720e55c6d5',1,'ChipmunkBitmapSampler']]],
  ['isclosed',['isClosed',['../interface_chipmunk_polyline.html#aa554c304a9c991350ac69c1ae4ce1adb',1,'ChipmunkPolyline']]],
  ['islocked',['isLocked',['../interface_chipmunk_space.html#aa6d66772a03214b8c28991301e47735b',1,'ChipmunkSpace']]],
  ['issleeping',['isSleeping',['../interface_chipmunk_body.html#aff377602948f0d6c9268342403ddf906',1,'ChipmunkBody']]],
  ['iterations',['iterations',['../interface_chipmunk_space.html#a14ae29e48719422333bc51ebfc292553',1,'ChipmunkSpace']]]
];
